<?php 
$translations = array(
	'General_Locale' => 'el_GR.UTF-8',
	'General_TranslatorName' => 'Jim Black www.jblack.info, Γεώργιος Τέλλος OnSite.Net VoIP & IT Solutions',
	'General_TranslatorEmail' => 'jimaek@hotmail.com, info@onsite.net.gr',
	'General_EnglishLanguageName' => 'Hellenic',
	'General_OriginalLanguageName' => 'Ελληνικά',
	'General_HelloUser' => 'Γεια σου, %s!',
	'General_OpenSourceWebAnalytics' => 'Λογισμικό Ανάλυσης Ιστοσελίδων',
	'General_YourDashboard' => 'Κεντρικός Πίνακας',
	'General_API' => 'API',
	'General_Widgets' => 'Widgets',
	'General_Settings' => 'Ρυθμίσεις',
	'General_GiveUsYourFeedback' => 'Πείτε μας τις παρατηρήσεις σας!',
	'General_Unknown' => 'Άγνωστο',
	'General_Required' => '%s required',
	'General_Error' => 'Σφάλμα',
	'General_Warning' => 'Προειδοποίηση',
	'General_BackToHomepage' => 'Πίσω στην αρχική σελίδα του Piwik',
	'General_Yes' => 'Ναι',
	'General_No' => 'Όχι',
	'General_Delete' => 'Διαγραφή',
	'General_Edit' => 'Επεξεργασία',
	'General_Ok' => 'Εντάξει',
	'General_Close' => 'Κλείσιμο',
	'General_Logout' => 'Αποσύνδεση',
	'General_Done' => 'Έγινε',
	'General_LoadingData' => 'Φόρτωση δεδομένων...',
	'General_ErrorRequest' => 'Ούπς&hellip; ίσως πρόβλημα με τη σύνδεση, παρακαλώ ξαναπροσπαθήστε.',
	'General_Next' => 'Επόμενο',
	'General_Previous' => 'Προηγούμενο',
	'General_Search' => 'Αναζήτηση',
	'General_Others' => 'Άλλα',
	'General_Table' => 'Πίνακας',
	'General_Piechart' => 'Γράφημα πίτας',
	'General_TagCloud' => 'Σύννεφο λέξεων',
	'General_VBarGraph' => 'Κάθετο γράφημα με μπάρες',
	'General_Export' => 'Εξαγωγή',
	'General_Refresh' => 'Ανανέωση της σελίδας',
	'General_Visitors' => 'Επισκέπτες',
	'General_ColumnNbUniqVisitors' => 'Μοναδικοί επισκέπτες',
	'General_ColumnNbVisits' => 'Επισκέψεις',
	'General_ColumnLabel' => 'Ετικέτα',
	'General_ColumnActionsPerVisit' => 'Ενέργειες ανά επίσκεψη',
	'General_ColumnAvgTimeOnSite' => 'Μέσος χρόνος στην ιστοσελίδα',
	'General_ColumnBounceRate' => 'Ρυθμός αναπήδησης',
	'General_ColumnPageviews' => 'Θεάσεις σελίδων',
	'General_ColumnUniquePageviews' => 'Μοναδικές θεάσεις σελίδων',
	'General_Save' => 'Αποθήκευση',
	'General_Website' => 'Ιστοσελίδα',
	'General_NoDataForGraph' => 'Ανεπαρκή δεδομένα για γράφημα',
	'General_NoDataForTagCloud' => 'Ανεπαρκή δεδομένα για σύννεφο λέξεων.',
	'General_DisplayNormalTable' => 'Εμφάνιση κανονικού πίνακα',
	'General_DisplayMoreData' => 'Εμφάνιση περισσότερων δεδομένων',
	'General_PiwikIsACollaborativeProject' => 'Έκδοση %s Piwik %s . %s Υπό δοκιμή %s επικοινωνία εδώ!%s.',
	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Βλέπετε την έκδοση παρουσίασης του %s; %sκατεβάστε%s την πλήρη έκδοση! Δείτε εδώ %s ',
	'General_Loading' => 'Φόρτωση...',
	'General_ExportAsImage' => 'Εξαγωγή ως εικόνα',
	'General_SaveImageOnYourComputer' => 'Για να αποθηκεύσετε την εικόνα στον υπολογιστή,δεξί κλικ πάνω στην εικόνα και επιλέξτε "Αποθήκευση εικόνας ως..."',
	'General_ColumnNbActions' => 'Ενέργειες',
	'General_ColumnMaxActions' => 'Μέγιστες ενέργειες σε μια επίσκεψη',
	'General_ColumnSumVisitLength' => 'Συνολικός χρόνος ξοδεμένος από τους επισκέπτες(σε δευτερόλεπτα)',
	'General_ColumnValuePerVisit' => 'Τιμή ανά επίσκεψη',
	'General_ColumnVisitsWithConversions' => 'Τιμή με μετατροπές',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Το Piwik %s είναι ένα ομαδικό πρότζεκτ. %s Εάν σας αρέσει το Piwik, μπορείτε να βοηθήσετε! Δείτε εδώ %s  Πως να συμβάλω στο Piwik;%s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s είναι διαθέσιμο. %s Παρακαλώ ενημερώστε το τώρα!%s (δείτε %s αλλαγές%s).',
	'General_BackToPiwik' => 'Πίσω στο Piwik',
	'General_ShortMonth_1' => 'Ιαν',
	'General_ShortMonth_2' => 'Φεβ',
	'General_ShortMonth_3' => 'Μρ',
	'General_ShortMonth_4' => 'Απρ',
	'General_ShortMonth_5' => 'Μαι',
	'General_ShortMonth_6' => 'Ιον',
	'General_ShortMonth_7' => 'Ιολ',
	'General_ShortMonth_8' => 'Αυγ',
	'General_ShortMonth_9' => 'Σεπ',
	'General_ShortMonth_10' => 'Οκτ',
	'General_ShortMonth_11' => 'Νοε',
	'General_ShortMonth_12' => 'Δεκ',
	'General_LongMonth_1' => 'Ιανουάριος',
	'General_LongMonth_2' => 'Φεβρουάριος ',
	'General_LongMonth_3' => 'Μάρτιος ',
	'General_LongMonth_4' => 'Απρίλιος ',
	'General_LongMonth_5' => 'Μάιος ',
	'General_LongMonth_6' => 'Ιούνιος ',
	'General_LongMonth_7' => 'Ιούλιος ',
	'General_LongMonth_8' => 'Αύγουστος ',
	'General_LongMonth_9' => 'Σεπτέμβριος ',
	'General_LongMonth_10' => 'Οκτώβριος ',
	'General_LongMonth_11' => 'Νοέμβριος ',
	'General_LongMonth_12' => 'Δεκέμβριος',
	'General_ShortDay_1' => 'Δε',
	'General_ShortDay_2' => 'Τρ',
	'General_ShortDay_3' => 'Τε',
	'General_ShortDay_4' => 'Πε',
	'General_ShortDay_5' => 'Πα',
	'General_ShortDay_6' => 'Σα',
	'General_ShortDay_7' => 'Κυ',
	'General_LongDay_1' => 'Δευτέρα',
	'General_LongDay_2' => 'Τρίτη',
	'General_LongDay_3' => 'Τετάρτη',
	'General_LongDay_4' => 'Πέμπτη',
	'General_LongDay_5' => 'Παρασκευή',
	'General_LongDay_6' => 'Σάββατο',
	'General_LongDay_7' => 'Κυριακή',
	'API_QuickDocumentation' => '<h2>Συνοπτική τεκμηρίωση του API</h2><p>Αν δεν έχετε δεδομένα κίνησης για σήμερα μπορείτε να <a href=\'misc/generateVisits.php\' target=_blank>προσθέσετε ενδεικτικά δεδομένα</a> χρησιμοποιώντας την γεννήτρια επισκέψεων.</p><p>Μπορείτε να δοκιμάσετε τις διάφορες διαθέσιμες μορφές για κάθε μέθοδο. Είναι πολύ εύκολο να εξάγετε ότι δεδομένα θέλετε από το piwik!</p><p><b>Για περισσότερες πληροφορίες ρίξτε μια ματιά στη διεύθυνση <a href=\'http://dev.piwik.org/trac/wiki/API\'>Επίσημη τεκμηρίωση API</a> ή <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API Reference</a>.</b></P><h2>Αυθεντικοποίηση χρήστη</h2><p>Αν θέλετε να <b>καλείτε τα δεδομένα μέσα στα scripts σας, μέσω crontab, κτλ. </b> πρέπει να προσθέσετε την παράμετρο <code><u>&token_auth=%s</u></code> στα URL που κάνουν κλήσεις στο API και θέλουν αυθεντικοποίηση.</p><p>Αυτό το token_auth είναι μυστικό όσο και το όνομα χρήστη και ο κωδικός σας, <b>μη τον μοιράζεστε!</p>',
	'API_LoadedAPIs' => 'Φορτώθηκαν επιτυχώς %s APIs',
	'Actions_Actions' => 'Ενέργειες',
	'Actions_SubmenuPages' => 'Σελίδες',
	'Actions_SubmenuOutlinks' => 'Δεσμοί εξόδου',
	'Actions_SubmenuDownloads' => 'Μεταφορτώσεις',
	'CoreHome_NoPrivileges' => 'You are logged in as \'%s\' but it seems you don\'t have any permission set in Piwik.<br />Ask your Piwik administrator to give you \'view\' access to a website.',
	'CoreHome_JavascriptDisabled' => 'JavaScript must be enabled in order for you to use Piwik in standard view.<br />However, it seems JavaScript is either disabled or not supported by your browser.<br />To use standard view, enable JavaScript by changing your browser options, then %1stry again%2s.<br />',
	'CoreHome_TableNoData' => 'Ανεπαρκή δεδομένα για πίνακα.',
	'CoreHome_CategoryNoData' => 'Ανεπαρκή δεδομένα στη κατηγορία. Δοκιμάστε να συμπεριλάβετε όλο το πλήθος.',
	'CoreHome_ShowJSCode' => 'Εμφάνιση του κώδικα της Javascript προς εισαγωγή',
	'CoreHome_IncludeAllPopulation_js' => 'Συμπερίληψη όλου του πλήθους',
	'CoreHome_ExcludeLowPopulation_js' => 'Εξαίρεση χαμηλού πλήθους',
	'CoreHome_PageOf_js' => '%s of %s',
	'CoreHome_Loading_js' => 'Φόρτωση...',
	'CoreHome_LocalizedDateFormat' => '%A %d %B %Y',
	'CoreHome_PeriodDay' => 'Μέρα',
	'CoreHome_PeriodWeek' => 'Εβδομάδα',
	'CoreHome_PeriodMonth' => 'Μήνας',
	'CoreHome_PeriodYear' => 'Χρόνος',
	'CoreHome_DaySu_js' => 'Κυ',
	'CoreHome_DayMo_js' => 'Δε',
	'CoreHome_DayTu_js' => 'Τρ',
	'CoreHome_DayWe_js' => 'Τε',
	'CoreHome_DayTh_js' => 'Πε',
	'CoreHome_DayFr_js' => 'Πα',
	'CoreHome_DaySa_js' => 'Σα',
	'CoreHome_ShortDay_1_js' => 'Κυρ',
	'CoreHome_ShortDay_2_js' => 'Δευ',
	'CoreHome_ShortDay_3_js' => 'Τρι',
	'CoreHome_ShortDay_4_js' => 'Τετ',
	'CoreHome_ShortDay_5_js' => 'Πεμ',
	'CoreHome_ShortDay_6_js' => 'Παρ',
	'CoreHome_ShortDay_7_js' => 'Σαβ',
	'CoreHome_LongDay_1_js' => 'Κυριακή',
	'CoreHome_LongDay_2_js' => 'Δευτέρα',
	'CoreHome_LongDay_3_js' => 'Τρίτη',
	'CoreHome_LongDay_4_js' => 'Τετάρτη',
	'CoreHome_LongDay_5_js' => 'Πέμπτη',
	'CoreHome_LongDay_6_js' => 'Παρασκευή',
	'CoreHome_LongDay_7_js' => 'Σάββατο',
	'CoreHome_ShortMonth_1_js' => 'Ιαν',
	'CoreHome_ShortMonth_2_js' => 'Φεβ',
	'CoreHome_ShortMonth_3_js' => 'Μαρ',
	'CoreHome_ShortMonth_4_js' => 'Απρ',
	'CoreHome_ShortMonth_5_js' => 'Μαι',
	'CoreHome_ShortMonth_6_js' => 'Ιουν',
	'CoreHome_ShortMonth_7_js' => 'Ιουλ',
	'CoreHome_ShortMonth_8_js' => 'Αυγ',
	'CoreHome_ShortMonth_9_js' => 'Σεπ',
	'CoreHome_ShortMonth_10_js' => 'Οκτ',
	'CoreHome_ShortMonth_11_js' => 'Νοε',
	'CoreHome_ShortMonth_12_js' => 'Δεκ',
	'CoreHome_MonthJanuary_js' => 'Ιανουάριος',
	'CoreHome_MonthFebruary_js' => 'Φεβρουάριος',
	'CoreHome_MonthMarch_js' => 'Μάρτιος',
	'CoreHome_MonthApril_js' => 'Απρίλιος',
	'CoreHome_MonthMay_js' => 'Μάιος',
	'CoreHome_MonthJune_js' => 'Ιούνιος',
	'CoreHome_MonthJuly_js' => 'Ιούλιος',
	'CoreHome_MonthAugust_js' => 'Αύγουστος',
	'CoreHome_MonthSeptember_js' => 'Σεπτέμβριος',
	'CoreHome_MonthOctober_js' => 'Οκτώβριος',
	'CoreHome_MonthNovember_js' => 'Νοέμβριος',
	'CoreHome_MonthDecember_js' => 'Δεκέμβριος',
	'CorePluginsAdmin_Plugins' => 'Plugins',
	'CorePluginsAdmin_PluginsManagement' => 'Διαχείριση προσθέτων',
	'CorePluginsAdmin_MainDescription' => 'Τα πρόσθετα (Plugins) επεκτείνουν και διευρύνουν την λειτουργικότητα του Piwik. Αφού εγκατασταθεί ένα πρόσθετο, μπορείτε να το ενεργοποιήσετε ή να το απενεργοποιήσετε εδώ.',
	'CorePluginsAdmin_Plugin' => 'Πρόσθετο',
	'CorePluginsAdmin_Version' => 'Έκδοση',
	'CorePluginsAdmin_Description' => 'Περιγραφή',
	'CorePluginsAdmin_Status' => 'Κατάσταση',
	'CorePluginsAdmin_Action' => 'Ενέργεια',
	'CorePluginsAdmin_PluginHomepage' => 'Ιστοσελίδα πρόσθετου',
	'CorePluginsAdmin_Activated' => 'Ενεργοποιημένο',
	'CorePluginsAdmin_Active' => 'Ενεργό',
	'CorePluginsAdmin_Inactive' => 'Ανενεργό',
	'CorePluginsAdmin_ActivatedHelp' => 'Αυτό το πρόσθετο δεν μπορεί να απενεργοποιηθεί',
	'CorePluginsAdmin_Deactivate' => 'Απενεργοποίηση',
	'CorePluginsAdmin_Activate' => 'Ενεργοποίηση',
	'CorePluginsAdmin_MenuPlugins' => 'Πρόσθετα',
	'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; Ενημέρωση',
	'CoreUpdater_UpdateRequired' => 'Απαραίτητη ενημέρωση',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Η βάση δεδομένων του Piwik είναι παλιά και πρέπει να αναβαθμιστεί προτού συνεχίσετε.',
	'CoreUpdater_PiwikWillBeUpgradedToVersionX' => 'Το Piwik θα αναβαθμιστεί στην έκδοση %s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Τα ακόλουθα πρόσθετα θα αναβαθμιστούν: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Η διαδικασία αναβάθμισης μπορεί να πάρει λίγο χρόνο, παρακαλώ περιμένετε.',
	'CoreUpdater_UpgradePiwik' => 'Αναβάθμιση Piwik',
	'CoreUpdater_HelpMessageContent' => 'Ελέγξτε τα %s Piwik FAQ %s για συνήθη σφάλματα κατά τη διαδικασία της αναβάθμισης. %s Ρωτήστε τον διαχειριστή του συστήματος και ζητήστε βοήθεια με το σφάλμα το οποίο κατά πάσα πιθανότητα είναι συναφή με τον διακομιστή και την MySQL.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Κρίσιμο σφάλμα κατά τη διαδικασία αναβάθμισης:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Το παραπάνω είναι το μήνυμα λάθους του πυρήνα. Λογικά πρέπει να βοηθάει την επεξήγηση της αιτίας, αλλά αν θέλετε περισσότερες πληροφορίες:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Η αναβάθμιση ολοκληρώθηκε με επιτυχία, αλλά υπήρξαν κάποια θέματα κατά τη διάρκεια. Παρακαλώ διαβάστε τις παραπάνω περιγραφές για τις λεπτομέριες. Για περισσότερη βοήθεια:',
	'CoreUpdater_UpgradeComplete' => 'Η αναβάθμιση ολοκληρώθηκε!',
	'CoreUpdater_WarningMessages' => 'Προειδοποιητικά μηνύματα:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Σφάλμα κατά την αναβάθμιση των πρόσθετων:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Απενεργοποιήθηκαν τα παρακάτω πρόσθετα: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Το Piwik αναβαθμίστηκε επιτυχώς!',
	'CoreUpdater_ContinueToPiwik' => 'Συνέχεια στο Piwik',
	'DBStats_DatabaseUsage' => 'Χρήση βάσης δεδομένων',
	'DBStats_MainDescription' => 'Το Piwik αποθηκεύει όλα τα δεδομένα της ανάλυσης στη βάση δεδομένων της Mysql . Τώρα, οι πίνακες του Piwik χρησιμοποιούν %s.',
	'DBStats_Table' => 'Πίνακας',
	'DBStats_RowNumber' => 'Αριθμός σειρών',
	'DBStats_DataSize' => 'Μέγεθος δεδομένων',
	'DBStats_IndexSize' => 'Μέγεθος ευρετηρίου',
	'DBStats_TotalSize' => 'Συνολικό μέγεθος',
	'Dashboard_Dashboard' => 'Πίνακας',
	'Dashboard_AddWidget' => 'Προσθήκη widget...',
	'Dashboard_DeleteWidgetConfirm' => 'Είστε σίγουρος ότι θέλετε να αφαιρέσετε αυτό το widget από τον πίνακα?',
	'Dashboard_SelectWidget' => 'Επιλέξτε το widget για προσθήκη στο πίνακα',
	'Dashboard_AddPreviewedWidget' => 'Προσθήκη του widget της προεπισκόπησης στο πίνακα',
	'Dashboard_WidgetPreview' => 'Προεπισκόπηση Widget',
	'Dashboard_TitleWidgetInDashboard_js' => 'Το Widget είναι ήδη στο πίνακα',
	'Dashboard_TitleClickToAdd_js' => 'Πατήστε για προσθήκη στο πίνακα',
	'Dashboard_LoadingPreview_js' => 'Φόρτωση προεπισκόπησης, παρακαλώ περιμένετε...',
	'Dashboard_LoadingWidget_js' => 'Φόρτωση widget, παρακαλώ περιμένετε...',
	'Dashboard_WidgetNotFound_js' => 'Το Widget δεν βρέθηκε',
	'Installation_Installation' => 'Εγκατάσταση',
	'Installation_InstallationStatus' => 'Κατάσταση εγκατάστασης',
	'Installation_PercentDone' => '%s %% Έγινε',
	'Installation_NoConfigFound' => 'The Piwik configuration file couldn\'t be found and you are trying to access a Piwik page.<br /><b>&nbsp;&nbsp;&raquo; You can <a href=\'index.php\'>install Piwik now</a></b><br /><small>If you installed Piwik before and have some tables in your DB, don\'t worry, you can reuse the same tables and keep your existing data!</small>',
	'Installation_MysqlSetup' => 'Mysql database setup',
	'Installation_MysqlErrorConnect' => 'Σφάλμα κατά την προσπάθεια σύνδεσης με της βάση δεδομένων της Mysql',
	'Installation_JsTag' => 'Javascript tag',
	'Installation_JsTagHelp' => '<p>Για να γίνει σωστή καταμέτρηση όλων των επισκεπτών, πρέπει να εισάγετε τον κώδικα Javascript σε όλες σας τις σελίδες.</p><p>Οι σελίδες σας δεν είναι ανάγκη να είναι γραμμένες σε PHP, το Piwik θα δουλέψει σε σελίδες όλων των ειδών (είτε είναι HTML, ASP, Perl ή οποιαδήποτε άλλη γλώσσα προγραμματισμού).</p><p>Ορίστε ο κώδικας που πρέπει να εισάγετε: (αντιγράψτε και επικολλήστε σε όλες τις σελίδες σας) </p>',
	'Installation_Congratulations' => 'Συγχαρητήρια',
	'Installation_CongratulationsHelp' => '<p>Συγχαρητήρια! Η εγκατάσταση του Piwik έχει ολοκληρωθεί.</p><p>Σιγουρευτείτε ότι ο κώδικας Javascript έχει εισηχθεί στις ιστοσελίδες και περιμένετε για τους πρώτους επισκέπτες σας!</p>',
	'Installation_ContinueToPiwik' => 'Συνέχεια στο Piwik',
	'Installation_SetupWebsite' => 'Ρύθμιση μιας ιστοσελίδας',
	'Installation_SetupWebsiteError' => 'Συνέβη ένα σφάλμα κατά της προσθήκη του ιστοχώρου',
	'Installation_GeneralSetup' => 'Γενικές ρυθμίσεις',
	'Installation_GeneralSetupSuccess' => 'Οι γενικές ρυθμίσεις πραγματοποιήθηκαν με επιτυχία',
	'Installation_SystemCheck' => 'Έλεγχος συστήματος',
	'Installation_SystemCheckPhp' => 'Έκδοση PHP',
	'Installation_SystemCheckPdo' => 'Επέκταση Pdo',
	'Installation_SystemCheckPdoMysql' => 'Επέκταση Pdo_Mysql',
	'Installation_SystemCheckPdoError' => 'Πρέπει να ενεργοποιήσετε τις επεκτάσεις PDO και PDO_MYSQL στο αρχείο php.ini',
	'Installation_SystemCheckPdoHelp' => 'Σε ένα διακομιστή με Γουίντοουζ μπορείτε να προσθέσετε τις ακόλουθες γραμμές στο αρχείο php.ini %s <br /><br />Σε ένα διακομιστή με Λίνουξ μπορείτε να κάνετε compile την php με την ακόλουθη παράμετρο %s Μέσα στο αρχείο php.ini, προσθέστε τις ακόλουθες γραμμές %s<br /><br />Περισσότερες πληροφορίες μπορείτε να δείτε στον <a style="color:red" href="http://php.net/pdo">ιστοχώρο της PHP</a>.',
	'Installation_SystemCheckWriteDirs' => 'Υποφάκελοι με δικαίωμα εγγραφής',
	'Installation_SystemCheckWriteDirsHelp' => 'Για να διορθώσετε αυτό το σφάλμα στο Λίνουξ σύστημά σας δοκιμάστε να πληκτρολογήσετε τις ακόλουθες εντολές',
	'Installation_SystemCheckMemoryLimit' => 'Όριο μνήμης',
	'Installation_SystemCheckMemoryLimitHelp' => 'On a high traffic website, the archiving process may require more memory than currently allowed.<br />See the directive memory_limit in your php.ini file if necessary.',
	'Installation_SystemCheckGD' => 'GD &gt; 2.x (γραφικά)',
	'Installation_SystemCheckGDHelp' => 'Οι κορυφογραμμές (μικρά γραφήματα) δεν θα δουλεύουν.',
	'Installation_SystemCheckTimeLimit' => 'set_time_limit() επιτρέπεται',
	'Installation_SystemCheckTimeLimitHelp' => 'Σε ιστοχώρους με μεγάλη κίνηση, όταν διενεργείται η αποθήκευση ασφαλείας μπορεί να δαπανήσει περισσότερο χρόνο από ότι είναι προς το παρόν επιτρεπτό.<br />Δείτε την οδηγία max_execution_time στο αρχείο php.ini αν είναι απαραίτητο',
	'Installation_SystemCheckMail' => 'mail() επιτρέπεται',
	'Installation_SystemCheckError' => 'Συνέβη ένα σφάλμα – πρέπει να διορθωθεί πριν συνεχίσετε',
	'Installation_SystemCheckWarning' => 'Το Piwik θα δουλεύει κανονικά αλλά θα λείπουν κάποιες λειτουργίες',
	'Installation_Tables' => 'Δημιουργία πινάκων',
	'Installation_TablesWarning' => 'Κάποιοι <span id="linkToggle">Πίνακες του Piwik</span> είναι ήδη εγκατεστημένοι στη βάση δεδομένων',
	'Installation_TablesFound' => 'Οι ακόλουθοι πίνακες βρέθηκαν εντός της βάσης δεδομένων',
	'Installation_TablesWarningHelp' => 'Επιλέξτε να χρησιμοποιήσετε την υπάρχουσα βάση δεδομένων ή επιλέξτε να κάνετε μία καθαρή εγκατάσταση έτσι ώστε να καθαρίσει η βάση δεδομένων από όλα τα δεδομένα.',
	'Installation_TablesReuse' => 'Χρήση υπαρχόντων πινάκων',
	'Installation_TablesDelete' => 'Διαγραφή των πινάκων που ανιχνεύθηκαν',
	'Installation_TablesDeletedSuccess' => 'Υπάρχον πίνακες του Piwik διαγράφηκαν με επιτυχία',
	'Installation_TablesCreatedSuccess' => 'Οι πίνακες δημιουργήθηκαν επιτυχώς!',
	'Installation_DatabaseCreatedSuccess' => 'Η βάση δεδομένων %s δημιουργήθηκε επιτυχώς!',
	'Installation_TablesDeleteConfirm' => 'Είστε σίγουρος ότι θέλετε να διαγράψετε όλους τους πίνακες του Piwik από αυτή τη βάση δεδομένων?',
	'Installation_Welcome' => 'Καλωσορίσατε!',
	'Installation_WelcomeHelp' => '<p>Το Piwik είναι ένα λογισμικό ανοιχτού κώδικα ανάλυσης ιστοσελίδων που συλλέγει τις πληροφορίες που θέλετε από του επισκέπτες σας.</p><p>Αυτή η διαδικασία είναι χωρισμένη σε %s απλά βήματα και θα πάρει περίπου 5 λεπτά.</p>',
	'Login_LoginPasswordNotCorrect' => 'Το όνομα χρήστη και ο κωδικός δεν είναι σωστά',
	'Login_Login' => 'Όνομα χρήστη',
	'Login_Password' => 'Κωδικός',
	'Login_LoginOrEmail' => 'Χρήστης ή E-mail',
	'Login_LogIn' => 'Σύνδεση',
	'Login_Logout' => 'Αποσύνδεση',
	'Login_LostYourPassword' => 'Ξεχάσατε τον κωδικό σας?',
	'Login_RemindPassword' => 'Υπενθύμιση κωδικού',
	'Login_PasswordReminder' => 'Παρακαλώ συμπληρώστε το όνομα χρήστη και την ηλεκτρονική σας διεύθυνση. Θα λάβετε ένα μήνυμα που θα περιέχει ένα νέο κωδικό.',
	'Login_InvalidUsernameEmail' => 'Λανθασμένο όνομα χρήστη ή/και λάθος ηλεκτρονική διεύθυνση',
	'Login_MailTopicPasswordRecovery' => 'Ανάκτηση κωδικού',
	'Login_MailPasswordRecoveryBody' => 'Γεια σας %1s, \n\n Ο νέος σας κωδικός είναι: %2s \n\n Συνδεθείτε εδώ: %3s',
	'Login_PasswordSent' => 'Ο κωδικός σας μόλις απεστάλη. Ελέγξτε τα μηνύματά σας.',
	'Login_ContactAdmin' => 'Πιθανή αιτία: ο διακομιστής έχει απενεργοποιημένη τη διαδικασία mail() <br />Παρακαλώ επικοινωνήστε με τον διαχειριστή.',
	'Provider_WidgetProviders' => 'Πάροχοι',
	'Provider_SubmenuLocationsProvider' => 'Τοποθεσίες & πάροχοι',
	'Referers_Referers' => 'Referers',
	'Referers_SearchEngines' => 'Μηχανές αναζήτησης',
	'Referers_Keywords' => 'Λέξεις κλειδιά',
	'Referers_DirectEntry' => 'Απευθείας είσοδος',
	'Referers_Websites' => 'Ιστοχώροι',
	'Referers_Campaigns' => 'Εκστρατείες',
	'Referers_Evolution' => 'Εξέλιξη εντός περιόδου',
	'Referers_Type' => 'Referer Type',
	'Referers_TypeDirectEntries' => '%s απευθείας είσοδοι',
	'Referers_TypeSearchEngines' => '%s από μηχανές αναζήτησης',
	'Referers_TypeWebsites' => '%s από ιστοσελίδες',
	'Referers_TypeCampaigns' => '%s από εκστρατείες',
	'Referers_Other' => 'Άλλο',
	'Referers_OtherDistinctSearchEngines' => '%s διακριτές μηχανές αναζήτησης',
	'Referers_OtherDistinctKeywords' => '%s διακριτές λέξεις κλειδιά',
	'Referers_OtherDistinctWebsites' => '%1s διακριτές ιστοσελίδες (χρήση %2s διακριτών url)',
	'Referers_OtherDistinctCampaigns' => '%s διακριτές εκστρατείες',
	'Referers_TagCloud' => 'Έξοδος σύννεφου λέξεων',
	'Referers_SubmenuEvolution' => 'Εξέλιξη',
	'Referers_SubmenuSearchEngines' => 'Μηχανές αναζήτησης & λέξεις κλειδιά',
	'Referers_SubmenuWebsites' => 'Ιστοχώροι',
	'Referers_SubmenuCampaigns' => 'Εκστρατείες',
	'Referers_WidgetKeywords' => 'Λίστα λέξεων κλειδιών',
	'Referers_WidgetCampaigns' => 'Λίστα εκστρατειών',
	'Referers_WidgetExternalWebsites' => 'Λίστα εξωτερικών ιστοχώρων',
	'Referers_WidgetSearchEngines' => 'Καλύτερες μηχανές αναζήτησης',
	'Referers_WidgetOverview' => 'Συνολική εικόνα',
	'SitesManager_Sites' => 'Ιστοχώροι',
	'SitesManager_WebsitesManagement' => 'Διαχείριση ιστοχώρων',
	'SitesManager_MainDescription' => 'Το σύστημα αναλυτικών αναφορών χρειάζεται ιστοχώρους! Προσθέστε, ενημερώστε, διαγράψτε ιστοχώρους και εμφανίστε τον κώδικα Javascript που θα εισηχθεί στις ιστοσελίδες σας.',
	'SitesManager_JsCode' => 'Κώδικας Javascript',
	'SitesManager_JsCodeHelp' => 'Να ο κώδικας της Javascript για εισαγωγή σε όλες τις σελίδες σας',
	'SitesManager_ShowJsCode' => 'εμφάνιση κώδικα',
	'SitesManager_NoWebsites' => 'Δεν έχετε κάποιο ιστοχώρο για να διαχειριστείτε.',
	'SitesManager_AddSite' => 'Προσθήκη ιστοχώρου',
	'SitesManager_Id' => 'Id',
	'SitesManager_Name' => 'Όνομα',
	'SitesManager_Urls' => 'URLs',
	'SitesManager_MenuSites' => 'Ιστοχώροι',
	'SitesManager_DeleteConfirm_js' => 'Είστε σίγουρος ότι θέλετε να διαγράψετε τον ιστοχώρο %s?',
	'SitesManager_ExceptionDeleteSite' => 'Δεν είναι δυνατό να διαγράψετε αυτό τον ιστοχώρο διότι είναι ο μοναδικός εγγεγραμμένος. Προσθέστε πρώτα ένα νέο ιστοχώρο και μετά διαγράψτε τον πρώτο.',
	'SitesManager_ExceptionNoUrl' => 'Πρέπει να συμπληρώσετε τουλάχιστον ένα URL για τον ιστοχώρο σας.',
	'SitesManager_ExceptionEmptyName' => 'Το όνομα του ιστοχώρου δεν πρέπει να είναι κενό.',
	'SitesManager_ExceptionInvalidUrl' => 'Το url \'%s\' δεν είναι ένα έγγυρο URL.',
	'TranslationsAdmin_MenuTranslations' => 'Μεταφράσεις',
	'TranslationsAdmin_MenuLanguages' => 'Γλώσσες',
	'TranslationsAdmin_Plugin' => 'Πρόσθετο',
	'TranslationsAdmin_Definition' => 'Ορισμός',
	'TranslationsAdmin_DefaultString' => 'Προεπιλεγμένο αλφαριθμητικό (Αγγλικά)',
	'TranslationsAdmin_TranslationString' => 'Μεταφρασμένο αλφαριθμητικό (ενεργή γλώσσα: %s)',
	'TranslationsAdmin_Translations' => 'Μεταφράσεις',
	'TranslationsAdmin_FixPermissions' => 'Παρακαλώ διορθώστε τα δικαιώματα του συστήματος αρχείων',
	'TranslationsAdmin_AvailableLanguages' => 'Διαθέσιμες γλώσσες',
	'TranslationsAdmin_AddLanguage' => 'Προσθήκη γλώσσας',
	'TranslationsAdmin_LanguageCode' => 'Κωδικός γλώσσας',
	'TranslationsAdmin_Export' => 'Εξαγωγή γλώσσας',
	'TranslationsAdmin_Import' => 'Εισαγωγή γλώσσας',
	'UserCountry_Country' => 'Χώρα',
	'UserCountry_Continent' => 'Ήπειρος',
	'UserCountry_DistinctCountries' => '%s διακεκριμένες χώρες',
	'UserCountry_SubmenuLocations' => 'Τοποθεσίες',
	'UserCountry_WidgetContinents' => 'Ήπειροι επισκεπτών',
	'UserCountry_WidgetCountries' => 'Χώρες επισκεπτών',
	'UserCountry_country_ac' => 'Ascension Islands',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'United Arab Emirates',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua and Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albania',
	'UserCountry_country_am' => 'Armenia',
	'UserCountry_country_an' => 'Netherlands Antilles',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarctica',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'American Samoa',
	'UserCountry_country_at' => 'Austria',
	'UserCountry_country_au' => 'Australia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_az' => 'Azerbaijan',
	'UserCountry_country_ba' => 'Bosnia and Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgium',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaria',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brazil',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bv' => 'Bouvet Island',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Belarus',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Canada',
	'UserCountry_country_cc' => 'Cocos (Keeling) Islands',
	'UserCountry_country_cd' => 'Congo, The Democratic Republic of the',
	'UserCountry_country_cf' => 'Central African Republic',
	'UserCountry_country_cg' => 'Congo',
	'UserCountry_country_ch' => 'Switzerland',
	'UserCountry_country_ci' => 'Cote D\'Ivoire',
	'UserCountry_country_ck' => 'Cook Islands',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Cameroon',
	'UserCountry_country_cn' => 'China',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cape Verde',
	'UserCountry_country_cx' => 'Christmas Island',
	'UserCountry_country_cy' => 'Cyprus',
	'UserCountry_country_cz' => 'Czech Republic',
	'UserCountry_country_de' => 'Germany',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Denmark',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'Dominican Republic',
	'UserCountry_country_dz' => 'Algeria',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egypt',
	'UserCountry_country_eh' => 'Western Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Spain',
	'UserCountry_country_et' => 'Ethiopia',
	'UserCountry_country_fi' => 'Finland',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falkland Islands (Malvinas)',
	'UserCountry_country_fm' => 'Micronesia, Federated States of',
	'UserCountry_country_fo' => 'Faroe Islands',
	'UserCountry_country_fr' => 'France',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgia',
	'UserCountry_country_gf' => 'French Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Greenland',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Equatorial Guinea',
	'UserCountry_country_gr' => 'Ελλάδα',
	'UserCountry_country_gs' => 'South Georgia and the South Sandwich Islands',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard Island and McDonald Islands',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Croatia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hungary',
	'UserCountry_country_id' => 'Indonesia',
	'UserCountry_country_ie' => 'Ireland',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Man Island',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'British Indian Ocean Territory',
	'UserCountry_country_iq' => 'Iraq',
	'UserCountry_country_ir' => 'Iran, Islamic Republic of',
	'UserCountry_country_is' => 'Iceland',
	'UserCountry_country_it' => 'Italy',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordan',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kyrgyzstan',
	'UserCountry_country_kh' => 'Cambodia',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comoros',
	'UserCountry_country_kn' => 'Saint Kitts and Nevis',
	'UserCountry_country_kp' => 'Korea, Democratic People\'s Republic of',
	'UserCountry_country_kr' => 'Korea, Republic of',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Cayman Islands',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Lebanon',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lithuania',
	'UserCountry_country_lu' => 'Luxembourg',
	'UserCountry_country_lv' => 'Latvia',
	'UserCountry_country_ly' => 'Libya',
	'UserCountry_country_ma' => 'Morocco',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldova, Republic of',
	'UserCountry_country_mg' => 'Madagascar',
	'UserCountry_country_mh' => 'Marshall Islands',
	'UserCountry_country_mk' => 'Fyrom',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Northern Mariana Islands',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldives',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexico',
	'UserCountry_country_my' => 'Malaysia',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'New Caledonia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk Island',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Netherlands',
	'UserCountry_country_no' => 'Norway',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'New Zealand',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'French Polynesia',
	'UserCountry_country_pg' => 'Papua New Guinea',
	'UserCountry_country_ph' => 'Philippines',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Poland',
	'UserCountry_country_pm' => 'Saint Pierre and Miquelon',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestinian Territory',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Reunion Island',
	'UserCountry_country_ro' => 'Romania',
	'UserCountry_country_ru' => 'Russia',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudi Arabia',
	'UserCountry_country_sb' => 'Solomon Islands',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Sweden',
	'UserCountry_country_sg' => 'Singapore',
	'UserCountry_country_sh' => 'Saint Helena',
	'UserCountry_country_si' => 'Slovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovakia',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Suriname',
	'UserCountry_country_st' => 'Sao Tome and Principe',
	'UserCountry_country_su' => 'Old U.S.S.R',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Syrian Arab Republic',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_tc' => 'Turks and Caicos Islands',
	'UserCountry_country_td' => 'Chad',
	'UserCountry_country_tf' => 'French Southern Territories',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailand',
	'UserCountry_country_tj' => 'Tajikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'East Timor',
	'UserCountry_country_tr' => 'Turkey',
	'UserCountry_country_tt' => 'Trinidad and Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania, United Republic of',
	'UserCountry_country_ua' => 'Ukraine',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'United Kingdom',
	'UserCountry_country_gb' => 'Great Britain',
	'UserCountry_country_um' => 'United States Minor Outlying Islands',
	'UserCountry_country_us' => 'United States',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatican City',
	'UserCountry_country_vc' => 'Saint Vincent and the Grenadines',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Virgin Islands, British',
	'UserCountry_country_vi' => 'Virgin Islands, U.S.',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis and Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Yugoslavia',
	'UserCountry_country_za' => 'South Africa',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Ευρώπη',
	'UserCountry_continent_afr' => 'Αφρική',
	'UserCountry_continent_asi' => 'Ασία',
	'UserCountry_continent_ams' => 'Νοτια και Κεντρική Αμερική',
	'UserCountry_continent_amn' => 'Βόρεια Αμερική',
	'UserCountry_continent_oce' => 'Οκεανία',
	'UserSettings_BrowserFamilies' => 'Οικογένειες περιηγητών',
	'UserSettings_Browsers' => 'Περιηγητές',
	'UserSettings_Plugins' => 'Πρόσθετα',
	'UserSettings_Configurations' => 'Ρυθμίσεις',
	'UserSettings_OperatingSystems' => 'Λειτουργικά συστήματα',
	'UserSettings_Resolutions' => 'Αναλύσεις',
	'UserSettings_WideScreen' => 'Ευρεία οθόνη',
	'UserSettings_WidgetResolutions' => 'Αναλύσεις οθόνης',
	'UserSettings_WidgetBrowsers' => 'Περιηγητές επισκεπτών',
	'UserSettings_WidgetPlugins' => 'Λίστα προσθέτων',
	'UserSettings_WidgetWidescreen' => 'Κανονική / Ευρεία',
	'UserSettings_WidgetBrowserFamilies' => 'Περιηγητές ανά οικογένεια',
	'UserSettings_WidgetOperatingSystems' => 'Λειτουργικά συστήματα',
	'UserSettings_WidgetGlobalVisitors' => 'Γενικές ρυθμίσεις χρηστών',
	'UserSettings_SubmenuSettings' => 'Ρυθμίσεις',
	'VisitsSummary_NbVisits' => '%s επισκέψεις',
	'VisitsSummary_NbUniqueVisitors' => '%s μοναδικοί επισκέπτες',
	'VisitsSummary_NbActions' => '%s ενέργειες (θεάσεις σελίδων)',
	'VisitsSummary_TotalTime' => '%s συνολικός χρόνος δαπανήθηκε από τους επισκέπτες',
	'VisitsSummary_MaxNbActions' => '%s μέγιστες ενέργειες εντός μίας επίσκεψης',
	'VisitsSummary_NbBounced' => '%s επισκέπτες εκτινάχθηκαν (έφυγαν από την πρώτη σελίδα)',
	'VisitsSummary_Evolution' => 'Εξέλιξη εντός τελευταίων 30 %s',
	'VisitsSummary_Report' => 'Αναφορά',
	'VisitsSummary_GenerateTime' => '%s δευτερόλεπτα για τη δημιουργία της σελίδας',
	'VisitsSummary_GenerateQueries' => '%s επερωτήσεις εκτελέστηκαν',
	'VisitsSummary_WidgetLastVisits' => 'Γράφημα τελευταίων επισκέψεων',
	'VisitsSummary_WidgetVisits' => 'Εικόνα επισκέψεων',
	'VisitsSummary_WidgetLastVisitors' => 'Γράφημα τελευταίων μοναδικών επισκεπτών',
	'VisitsSummary_WidgetOverviewGraph' => 'Εικόνα με γράφημα',
	'VisitsSummary_SubmenuOverview' => 'Εικόνα',
	'VisitFrequency_Evolution' => 'Εξέλιξη εντός της περιόδου',
	'VisitFrequency_ReturnVisits' => '%s επιστρεφόμενες επισκέψεις',
	'VisitFrequency_ReturnActions' => '%s ενέργειες από τις επιστρεφόμενες επισκέψεις ',
	'VisitFrequency_ReturnMaxActions' => '%s μέγιστες ενέργειες από μία επιστρεφόμενη επίσκεψη',
	'VisitFrequency_ReturnTotalTime' => '%s συνολικός χρόνος δαπανήθηκε από τις επιστρεφόμενες επισκέψεις ',
	'VisitFrequency_ReturnBounces' => '%s φορές που μία επιστρεφόμενη επίσκεψη αναπήδησε (έφυγε από την πρώτη σελίδα)',
	'VisitFrequency_WidgetOverview' => 'Εικόνα συχνότητας',
	'VisitFrequency_WidgetGraphReturning' => 'Γράφημα επιστρεφόμενων επισκέψεων',
	'VisitFrequency_SubmenuFrequency' => 'Συχνότητα',
	'VisitTime_LocalTime' => 'Επισκέψεις ανά τοπική ώρα',
	'VisitTime_ServerTime' => 'Επισκέψεις ανά ώρα διακομιστή',
	'VisitTime_WidgetLocalTime' => 'Επισκέψεις ανά τοπική ώρα',
	'VisitTime_WidgetServerTime' => 'Επισκέψεις ανά ώρα διακομιστή',
	'VisitTime_SubmenuTimes' => 'Χρόνοι',
	'VisitTime_NHour' => '%sh',
	'VisitorInterest_VisitsPerDuration' => 'Επισκέψεις ανά διάρκεια',
	'VisitorInterest_VisitsPerNbOfPages' => 'Επισκέψεις ανά αριθμό σελίδων',
	'VisitorInterest_WidgetLengths' => 'Διάρκεια επισκέψεων',
	'VisitorInterest_WidgetPages' => 'Σελίδες ανά επίσκεψη',
	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Συχνότητα & αφοσίωση',
	'VisitorInterest_PlusXMin' => '%s λεπ',
	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s λεπ',
	'VisitorInterest_OnePage' => '1 σελίδα',
	'VisitorInterest_NPages' => '%s σελίδες',
	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
	'Login_LoginPasswordNotCorrect' => 'Το όνομα χρήστη και ο κωδικός δεν είναι σωστά',
	'Login_Login' => 'Όνομα χρήστη',
	'Login_Password' => 'Κωδικός',
	'Login_LoginOrEmail' => 'Χρήστης ή E-mail',
	'Login_LogIn' => 'Σύνδεση',
	'Login_Logout' => 'Αποσύνδεση',
	'Login_LostYourPassword' => 'Ξεχάσατε τον κωδικό σας?',
	'Login_RemindPassword' => 'Υπενθύμιση κωδικού',
	'Login_PasswordReminder' => 'Παρακαλώ συμπληρώστε το όνομα χρήστη και την ηλεκτρονική σας διεύθυνση. Θα λάβετε ένα μήνυμα που θα περιέχει ένα νέο κωδικό.',
	'Login_InvalidUsernameEmail' => 'Λανθασμένο όνομα χρήστη ή/και λάθος ηλεκτρονική διεύθυνση',
	'Login_MailTopicPasswordRecovery' => 'Ανάκτηση κωδικού',
	'Login_MailPasswordRecoveryBody' => 'Γεια σας %1s, \n\n Ο νέος σας κωδικός είναι: %2s \n\n Συνδεθείτε εδώ: %3s',
	'Login_PasswordSent' => 'Ο κωδικός σας μόλις απεστάλη. Ελέγξτε τα μηνύματά σας.',
	'Login_ContactAdmin' => 'Πιθανή αιτία: ο διακομιστής έχει απενεργοποιημένη τη διαδικασία mail() <br />Παρακαλώ επικοινωνήστε με τον διαχειριστή.',
	'UsersManager_UsersManagement' => 'Διαχείριση χρηστών',
	'UsersManager_UsersManagementMainDescription' => 'Δημιουργήστε νέους χρήστες ή ενημερώστε τους υπάρχοντες. Μπορείτε επίσης να αλλάξετε τα δικαιώματά τους  (παραπάνω).',
	'UsersManager_ManageAccess' => 'Διαχείριση πρόσβασης',
	'UsersManager_MainDescription' => 'Ρυθμίστε ποιοι χρήστες θα έχουν πρόσβαση σε ποιους ιστοχώρους. Μπορείτε επίσης να ρυθμίσετε τα δικαιώματα για όλους τους ιστοχώρους με μία κίνηση.',
	'UsersManager_Sites' => 'ιστοχώροι',
	'UsersManager_AllWebsites' => 'Όλοι οι ιστοχώροι',
	'UsersManager_ApplyToAllWebsites' => 'Εφαρμογή σε όλους τους ιστοχώρους',
	'UsersManager_User' => 'Χρήστης',
	'UsersManager_PrivNone' => 'Χωρίς πρόσβαση',
	'UsersManager_PrivView' => 'Εμφάνιση',
	'UsersManager_PrivAdmin' => 'Διαχείριση',
	'UsersManager_ChangeAllConfirm' => 'Είστε σίγουρος ότι θέλετε να αλλάξετε \'%s\' δικαιώματα σε όλες τις ιστοσελίδες?',
	'UsersManager_Login' => 'Σύνδεση',
	'UsersManager_Password' => 'Κωδικός',
	'UsersManager_Email' => 'Email',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_Token' => 'token_auth',
	'UsersManager_Edit' => 'Επεξεργασία',
	'UsersManager_AddUser' => 'Προσθήκη νέου χρήστη',
	'UsersManager_MenuUsers' => 'Χρήστες',
	'UsersManager_DeleteConfirm_js' => 'Είστε σίγουρος ότι θέλετε να διαγράψετε την χρήστη %s?',
	'UsersManager_ExceptionLoginExists' => 'Ο χρήστης \'%s\' υπάρχει ήδη.',
	'UsersManager_ExceptionEmailExists' => 'Χρήστης με το email \'%s\' υπάρχει ήδη.',
	'UsersManager_ExceptionInvalidLogin' => 'Το όνομα χρήστη πρέπει να είναι τουλάχιστον 3 χαρακτήρες και πρέπει να περιέχει μόνο λατινικά γράμματα και αριθμούς',
	'UsersManager_ExceptionInvalidPassword' => 'Το μήκος του κωδικού πρέπει να είναι από 6 χαρακτήρες ως 26.',
	'UsersManager_ExceptionInvalidEmail' => 'Το email δεν φαίνεται να είναι σωστό.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Ο χρήστης \'%s\' δεν υπάρχει και άρα δεν μπορεί να διαγραφεί.',
	'UsersManager_ExceptionAdminAnonymous' => 'Δεν μπορείτε να δώσετε διακαιώματα διαχειριστή στον \'anonymous\' χρήστη.',
	'UsersManager_ExceptionEditAnonymous' => 'Ο anonymous χρήστης δεν μπορεί να διαγραφεί ή να δεχθεί τροποποίηση. Χρησιμοποιείται από το Piwik για τον ορισμό του χρήστη που δεν έχει συνδεθεί ακόμα. Για παράδειγμα, μπορείτε να κάνετε τα στατιστικά σας δημόσια δίνοντας δικαίωμα \'προβολή\' στον χρήστη \'anonymous\'.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Ο χρήστης \'%s\' δεν υπάρχει.',
	'UsersManager_ExceptionAccessValues' => 'The parameter access must have one of the following values : [ %s ]',
	'VisitFrequency_Evolution' => 'Εξέλιξη εντός της περιόδου',
	'VisitFrequency_ReturnVisits' => '%s επιστρεφόμενες επισκέψεις',
	'VisitFrequency_ReturnActions' => '%s ενέργειες από τις επιστρεφόμενες επισκέψεις ',
	'VisitFrequency_ReturnMaxActions' => '%s μέγιστες ενέργειες από μία επιστρεφόμενη επίσκεψη',
	'VisitFrequency_ReturnTotalTime' => '%s συνολικός χρόνος δαπανήθηκε από τις επιστρεφόμενες επισκέψεις ',
	'VisitFrequency_ReturnBounces' => '%s φορές που μία επιστρεφόμενη επίσκεψη αναπήδησε (έφυγε από την πρώτη σελίδα)',
	'VisitFrequency_WidgetOverview' => 'Εικόνα συχνότητας',
	'VisitFrequency_WidgetGraphReturning' => 'Γράφημα επιστρεφόμενων επισκέψεων',
	'VisitFrequency_SubmenuFrequency' => 'Συχνότητα',
	'VisitTime_LocalTime' => 'Επισκέψεις ανά τοπική ώρα',
	'VisitTime_ServerTime' => 'Επισκέψεις ανά ώρα διακομιστή',
	'VisitTime_WidgetLocalTime' => 'Επισκέψεις ανά τοπική ώρα',
	'VisitTime_WidgetServerTime' => 'Επισκέψεις ανά ώρα διακομιστή',
	'VisitTime_SubmenuTimes' => 'Χρόνοι',
	'VisitTime_NHour' => '%sh',
	'VisitorInterest_VisitsPerDuration' => 'Επισκέψεις ανά διάρκεια',
	'VisitorInterest_VisitsPerNbOfPages' => 'Επισκέψεις ανά αριθμό σελίδων',
	'VisitorInterest_WidgetLengths' => 'Διάρκεια επισκέψεων',
	'VisitorInterest_WidgetPages' => 'Σελίδες ανά επίσκεψη',
	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Συχνότητα & αφοσίωση',
	'VisitorInterest_PlusXMin' => '%s λεπ',
	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s λεπ',
	'VisitorInterest_OnePage' => '1 σελίδα',
	'VisitorInterest_NPages' => '%s σελίδες',
	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
	'VisitsSummary_NbVisits' => '%s επισκέψεις',
	'VisitsSummary_NbUniqueVisitors' => '%s μοναδικοί επισκέπτες',
	'VisitsSummary_NbActions' => '%s ενέργειες (θεάσεις σελίδων)',
	'VisitsSummary_TotalTime' => '%s συνολικός χρόνος δαπανήθηκε από τους επισκέπτες',
	'VisitsSummary_MaxNbActions' => '%s μέγιστες ενέργειες εντός μίας επίσκεψης',
	'VisitsSummary_NbBounced' => '%s επισκέπτες εκτινάχθηκαν (έφυγαν από την πρώτη σελίδα)',
	'VisitsSummary_Evolution' => 'Εξέλιξη εντός τελευταίων 30 %ss',
	'VisitsSummary_Report' => 'Αναφορά',
	'VisitsSummary_GenerateTime' => '%s δευτερόλεπτα για τη δημιουργία της σελίδας',
	'VisitsSummary_GenerateQueries' => '%s επερωτήσεις εκτελέστηκαν',
	'VisitsSummary_WidgetLastVisits' => 'Γράφημα τελευταίων επισκέψεων',
	'VisitsSummary_WidgetVisits' => 'Εικόνα επισκέψεων',
	'VisitsSummary_WidgetLastVisitors' => 'Γράφημα τελευταίων μοναδικών επισκεπτών',
	'VisitsSummary_WidgetOverviewGraph' => 'Εικόνα με γράφημα',
	'VisitsSummary_SubmenuOverview' => 'Εικόνα',
);
